captureAnyNamed function
An argument matcher that matches any named argument passed in for the
parameter named named, and captures the argument for later access with
VerificationResult.captured.
See the README section on capturing arguments for examples.
Implementation
Null captureAnyNamed(String named) => _registerMatcher(
anything,
true,
named: named,
argumentMatcher: 'captureAnyNamed',
);